@@ -128,6 +128,36 @@ class QueenbeeTask(luigi.Task):
             f"{self.__class__.__name__}: finished copying artifacts..."
         )
 
+    def _create_optional_output_artifacts(self, dst):
+        """Create a dummy place holder for optional output artifacts.
+
+        Args:
+            dst: Execution folder
+        """
+        logger = self.get_interface_logger()
+        for art in self.output_artifacts:
+            is_optional = art.get('optional', False)
+            if not is_optional:
+                continue
+            artifact = pathlib.Path(dst, art['from'])
+            if artifact.exists():
+                continue
+            if 'type' not in art:
+                logger.exception(
+                    f"{self.__class__.__name__}: Optional artifact {art['name']} is "
+                    "missing type key. Try to regenerate the recipe with a newer "
+                    "version of queenbee-luigi."
+                )
+            output_type = art['type']
+            logger.info(
+                f"{self.__class__.__name__}: creating an empty {output_type} for "
+                f"optional artifact {art['name']} at {artifact} ..."
+            )
+            if output_type == 'folder':
+                artifact.mkdir(parents=True, exist_ok=True)
+            else:
+                artifact.write_text('')
+
     def _copy_output_artifacts(self, src):
         """Copy output artifacts to project folder.
 
@@ -143,6 +173,9 @@ class QueenbeeTask(luigi.Task):
             try:
                 _copy_artifacts(os.path.join(src, art['from']), art['to'])
             except Exception:
+                is_optional = art.get('optional', False)
+                if is_optional:
+                    continue
                 logger.exception(
                     f"Failed to copy output artifact: {art['name']} to {art['to']} ..."
                 )
@@ -227,6 +260,7 @@ class QueenbeeTask(luigi.Task):
             raise ValueError(err_msg)
 
         # copy the results file back
+        self._create_optional_output_artifacts(dst)
         self._copy_output_artifacts(dst)
         self._copy_output_parameters(dst)
         # change back to initial directory
